@@ -4,7 +4,7 @@ use warnings;
 no warnings qw(redefine);
 package RT::Extension::ConditionalCustomFields;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =encoding utf8
 
@@ -104,10 +104,7 @@ sub SetConditionedBy {
             Content => $value,
         );
     } elsif ($attr) {
-        ($ret, $msg) = $attr->Delete(
-            Name    => 'ConditionedBy',
-            Content => $value,
-        );
+        ($ret, $msg) = $attr->Delete;
     }
 
     if ($ret) {
